@@ -105,11 +105,8 @@ class ControllerAPI:
     def pelion_cmd_is_running(self,command):
         req_id = str(uuid.uuid4())
         status = self.__pelion_get(req_id,self.pelion_cmd_status_lwm2m_uri)
-        print("Raw Status: " + str(status))
         if command in status:
-            print("command is in status")
             if status[command] == 'running':
-                print(" Status: " + status[command] + " is RUNNING")
                 return True
         return False
     
@@ -117,7 +114,6 @@ class ControllerAPI:
     def pelion_cmd_in_error(self,command):
         req_id = str(uuid.uuid4())
         status = self.__pelion_get(req_id,self.pelion_cmd_status_lwm2m_uri)
-        print("Command Dict: " + str(status) + " Status: " + status[command])
         if command in status:
             if status[command] == 'error':
                 return True
